@@ -5,7 +5,7 @@ use strict;
 use Rose::DB::Object::Metadata::Column::Scalar;
 our @ISA = qw(Rose::DB::Object::Metadata::Column::Scalar);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub type { 'boolean' }
 
@@ -14,6 +14,11 @@ sub method_maker_type  { 'boolean' }
 sub parse_value  { shift; shift->parse_boolean(@_)  }
 sub format_value { shift; shift->format_boolean(@_) }
 
+sub perl_column_defintion_attributes
+{
+  grep { $_ ne 'length' } shift->SUPER::perl_column_defintion_attributes;
+}
+
 1;
 
 __END__
